const { GoogleGenerativeAI, GenerationConfig } = require("@google/generative-AI");

// Replace with your actual API key
const apiKey = process.env.GEMINI_KEY;

const genAI = new GoogleGenerativeAI(apiKey);

class geminiChatController {
  static async chatWithGemini(req, res) {
    try {
      const { userInput, conversationHistory = [] } = req.body;

      // Configuration for AI content generation
      const generationConfig = {
        maxOutputTokens: 500,
        temperature: 0.4,
        topP: 0.9,
      };

      const model = genAI.getGenerativeModel({ model: "gemini-pro", generationConfig });

      // Construct the prompt
      const promptHistory = conversationHistory.map(item => `${item.role}: ${item.text}`).join('\n');
      const prompt = `

**Conversation History:**

${conversationHistory.slice(-5).map(message => `  - ${message.role}: ${message.text}`).join('\n')}

**You said:** ${userInput}

**Desired Output:**

* Identify the user's intent related to parties or events (club night, house party, etc.).
* Consider the conversation history for context and user preferences.
* Please don't use word like **Suggested Response:**, **Assistant:** ,**Response:** etc at starting of response
* Provide informative and engaging responses to guide the user in finding the perfect event, avoiding phrases like "Assistant." 
  - Offer suggestions for different types of parties or events based on user clues (e.g., music genre, vibe).
  - If location sharing is enabled, personalize recommendations for nearby events.
  - Use an enthusiastic and helpful tone to create a positive user experience.
  - Ask clarifying questions if needed to understand the user's preferences better.
  - Avoid overly promotional language for specific events.


`;

      console.log(prompt);
      const result = await model.generateContent(prompt);
      const response = await result.response;
      const text = response.text();

      // Extract the user's (Gemini's) response from the generated text
      const userResponse = text; // Account for two lines

      res.status(200).json({ response: userResponse });
    } catch (error) {
      console.error('Error:', error);
      res.status(500).json({ error: 'Internal Server Error' }); // Handle errors gracefully
    }
  }
}

module.exports = geminiChatController;
